@@ -4,7 +4,8 @@ from contextlib import contextmanager
 
 from gtdbtk.biolib_lite.custom_help_formatter import ChangeTempAction
 from gtdbtk.biolib_lite.custom_help_formatter import CustomHelpFormatter
-from gtdbtk.config.config import AF_THRESHOLD, PPLACER_MIN_RAM_BAC
+from gtdbtk.config.config import AF_THRESHOLD, PPLACER_MIN_RAM_BAC_FULL, MASH_K_VALUE, MASH_S_VALUE, MASH_D_VALUE, \
+    MASH_V_VALUE, MASH_MAX_DISTANCE
 
 
 @contextmanager
@@ -73,6 +74,9 @@ def __extension(group):
     group.add_argument('-x', '--extension', type=str, default='fna',
                        help='extension of files to process, ``gz`` = gzipped')
 
+def __skip_ani_screen(group):
+    group.add_argument('--skip_ani_screen', action="store_true", default=False,
+                       help="Skip the ani_screening step to classify genomes using mash and FastANI ")
 
 def __skip_gtdb_refs(group):
     group.add_argument('--skip_gtdb_refs', action="store_true", default=False,
@@ -187,15 +191,15 @@ def __scratch_dir(group):
                        help='reduce pplacer memory usage by writing to disk (slower).')
 
 
-def __recalculate_red(group):
-    group.add_argument('-r', '--recalculate_red', default=False, action='store_true',
-                       help='recalculate RED values based on the reference tree and all added user genomes')
+# def __recalculate_red(group):
+#     group.add_argument('-r', '--recalculate_red', default=False, action='store_true',
+#                        help='recalculate RED values based on the reference tree and all added user genomes')
 
 
 def __full_tree(group):
     group.add_argument('-f', '--full_tree', default=False, action='store_true',
                        help='use the unsplit bacterial tree for the classify step; this is the original GTDB-Tk '
-                            f'approach (version < 2) and requires more than {PPLACER_MIN_RAM_BAC} GB of RAM to load the reference tree')
+                            f'approach (version < 2) and requires more than {PPLACER_MIN_RAM_BAC_FULL} GB of RAM to load the reference tree')
 
 
 def __identify_dir(group, required):
@@ -245,24 +249,28 @@ def __no_mash(group):
 
 
 def __mash_k(group):
-    group.add_argument('--mash_k', default=16, type=int,
+    group.add_argument('--mash_k', default=MASH_K_VALUE, type=int,
                        help='k-mer size [1-32]')
 
 
 def __mash_s(group):
-    group.add_argument('--mash_s', default=5000, type=int,
+    group.add_argument('--mash_s', default=MASH_S_VALUE, type=int,
                        help='maximum number of non-redundant hashes')
 
 
 def __mash_d(group):
-    group.add_argument('--mash_d', default=0.1, type=float,
+    group.add_argument('--mash_d', default=MASH_D_VALUE, type=float,
                        help='maximum distance to keep [0-1]')
 
 
 def __mash_v(group):
-    group.add_argument('--mash_v', default=1.0, type=float,
+    group.add_argument('--mash_v', default=MASH_V_VALUE, type=float,
                        help='maximum p-value to keep [0-1]')
 
+def __mash_max_distance(group):
+    group.add_argument('--mash_max_distance', default=MASH_MAX_DISTANCE, type=float,
+                       help='Maximum Mash distance to select a potential GTDB genome as representative '
+                            'of a user genome.')
 
 def __mash_db(group):
     group.add_argument('--mash_db', default=None, type=str,
@@ -310,6 +318,10 @@ def __write_single_copy_genes(group):
                        help='output unaligned single-copy marker genes')
 
 
+def __prescreen(grp):
+    pass
+
+
 def get_main_parser():
     # Setup the main, and sub parsers.
     main_parser = argparse.ArgumentParser(
@@ -343,6 +355,7 @@ def get_main_parser():
             __gamma(grp)
             __gtdbtk_classification_file(grp)
             __custom_taxonomy_file(grp)
+            __write_single_copy_genes(grp)
             __prefix(grp)
             __genes(grp)
             __cpus(grp)
@@ -359,6 +372,15 @@ def get_main_parser():
             __batchfile(grp)
         with arg_group(parser, 'required named arguments') as grp:
             __out_dir(grp, required=True)
+        with mutex_group(parser, required=True) as grp:
+            __skip_ani_screen(grp)
+            __mash_db(grp)
+        with arg_group(parser, 'optional Mash arguments') as grp:
+            __no_mash(grp)
+            __mash_k(grp)
+            __mash_s(grp)
+            __mash_v(grp)
+            __mash_max_distance(grp)
         with arg_group(parser, 'optional arguments') as grp:
             __full_tree(grp)
             __extension(grp)
@@ -369,7 +391,7 @@ def get_main_parser():
             __pplacer_cpus(grp)
             __force(grp)
             __scratch_dir(grp)
-            # __recalculate_red(grp)
+            __write_single_copy_genes(grp)
             __keep_intermediates(grp)
             __min_af(grp)
             __temp_dir(grp)
@@ -440,6 +462,15 @@ def get_main_parser():
         with arg_group(parser, 'required named arguments') as grp:
             __align_dir(grp, required=True)
             __out_dir(grp, required=True)
+        with mutex_group(parser, required=True) as grp:
+            __skip_ani_screen(grp)
+            __mash_db(grp)
+        with arg_group(parser, 'optional Mash arguments') as grp:
+            __no_mash(grp)
+            __mash_k(grp)
+            __mash_s(grp)
+            __mash_v(grp)
+            __mash_max_distance(grp)
         with arg_group(parser, 'optional arguments') as grp:
             __extension(grp)
             __prefix(grp)
@@ -447,7 +478,6 @@ def get_main_parser():
             __pplacer_cpus(grp)
             __scratch_dir(grp)
             __full_tree(grp)
-            # __recalculate_red(grp)
             __min_af(grp)
             __temp_dir(grp)
             __debug(grp)
